\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{thesis08}[2008/10/08 v.1]
\typeout{Document Style UAH Thesis. Escaped 9-Feb-1995 from D. G. Brown.}
\typeout{Adapted to LaTeX2e by Juanjo (contributor to LaTeX-Community)}
\typeout{www.latex-community.org}

% CLASS OPTIONS
\DeclareOption{10pt}{\PassOptionsToClass{10pt}{report}}
\DeclareOption{11pt}{\PassOptionsToClass{11pt}{report}}
\DeclareOption{12pt}{\PassOptionsToClass{12pt}{report}}
\DeclareOption{legalpaper}{\PassOptionsToClass{legalpaper}{report}}
\DeclareOption{letterpaper}{%
    \PassOptionsToClass{letterpaper}{report}}
\DeclareOption{executivepaper}{%
     \PassOptionsToClass{executivepaper}{report}}
\DeclareOption{a4paper}{\PassOptionsToClass{a4paper}{report}}
\DeclareOption{a5paper}{\PassOptionsToClass{a5paper}{report}}
\DeclareOption{b5paper}{\PassOptionsToClass{b5paper}{report}}
\DeclareOption{draft}{\PassOptionsToClass{draft}{report}}
\DeclareOption{final}{\PassOptionsToClass{final}{report}}
\DeclareOption{titlepage}{\PassOptionsToClass{titlepage}{report}}
\DeclareOption{notitlepage}{\PassOptionsToClass{notitlepage}{report}}
\DeclareOption{oneside}{\PassOptionsToClass{oneside}{report}}
\DeclareOption{twoside}{\PassOptionsToClass{twoside}{report}}
\DeclareOption{onecolumn}{\PassOptionsToClass{onecolumn}{report}}
\DeclareOption{twocolumn}{\PassOptionsToClass{twocolumn}{report}}
\DeclareOption{landscape}{\PassOptionsToClass{landscape}{report}}
\DeclareOption{openany}{\PassOptionsToClass{openany}{report}}
\DeclareOption{openright}{\PassOptionsToClass{openright}{report}}
\DeclareOption{leqno}{\PassOptionsToClass{leqno}{report}}
\DeclareOption{fleqno}{\PassOptionsToClass{fleqno}{report}}
\DeclareOption{openbib}{\PassOptionsToClass{openbib}{report}}
\ExecuteOptions{letterpaper,10pt,oneside,onecolumn,final,openany}
\ProcessOptions
\LoadClass{report}

% PAGE LAYOUT

\if@twoside 
   \oddsidemargin 21pt \evensidemargin 59pt \marginparwidth 85pt
\else 
   \oddsidemargin 40.25pt \evensidemargin 40.25pt \marginparwidth 68pt
\fi
\topmargin -28.5pt \headheight 12pt \headsep 25pt \footskip 26pt 
\textheight 637pt \textwidth 6 in  
\addtolength{\topmargin}{-12pt}

% SECTIONAL UNITS

% Part

\def\@part[#1]#2{%
    \ifnum \c@secnumdepth >-2\relax
      \refstepcounter{part}%
      \addcontentsline{toc}{part}{\thepart\hspace{1em}#1}%
    \else
      \addcontentsline{toc}{part}{#1}%
    \fi
    \markboth{}{}%
    {\centering
     \interlinepenalty \@M
     \normalfont
     \ifnum \c@secnumdepth >-2\relax
       \large\bfseries\MakeUppercase{\partname}\nobreakspace\thepart
       \par
       \vskip 20\p@
     \fi
     \large\bfseries\MakeUppercase{#2}\par}%
    \@endpart}
\def\@spart#1{%
    {\centering
     \interlinepenalty \@M
     \normalfont
     \large\bfseries\MakeUppercase{#1}\par}%
    \@endpart}

% Chapter

\def\@chapter[#1]#2{\ifnum \c@secnumdepth >\m@ne
      \refstepcounter{chapter}
      \typeout{\@chapapp\space\thechapter.}
      \addcontentsline{toc}{chapter}{%
         \protect\numberline{\thechapter.}#1}%
   \else
      \addcontentsline{toc}{chapter}{#1}%
   \fi
   \chaptermark{#1}%
   \if@twocolumn
      \@topnewpage[\@makechapterhead{#2}]
   \else 
      \@makechapterhead{#2} \@afterheading 
   \fi}

\def\@makechapterhead#1{%
  \vspace*{54\p@}%
  {\parindent \z@ \centering \normalfont
    \ifnum \c@secnumdepth >\m@ne
        \large\bfseries\MakeUppercase{\@chapapp}\space\thechapter
        \par\nobreak
        \vskip 28\p@
    \fi
    \interlinepenalty\@M
    \large\bfseries\MakeUppercase{#1}\par\nobreak
    \vskip 28\p@}}

\def\@makeschapterhead#1{%
  \vspace*{54\p@}%
  {\parindent \z@ \centering
    \normalfont
    \interlinepenalty\@M
    \large\bfseries\MakeUppercase{#1}\par\nobreak
    \vskip 28\p@}}

% Section, subsection, etc.

\renewcommand\section{\@startsection{section}{1}{\z@}%
   {3.5ex plus 1ex minus .2ex}{1.5ex plus .2ex}%
   {\normalfont\large\bfseries}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
   {3.25ex plus 1ex minus .2ex}{1.5ex plus .2ex}%
   {\normalfont\large\bfseries}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
   {3.25ex plus 1ex minus .2ex}{1.5ex plus .2ex}%
   {\normalfont\normalsize\bfseries}}
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
   {3.25ex plus 1ex minus .2ex}{-1em}%
   {\normalfont\normalsize\bfseries}}
\renewcommand\subparagraph{\@startsection{subparagraph}{5}%
   {\parindent}{3.25ex plus 1ex minus .2ex}{-1em}%
   {\normalfont\normalsize\bfseries}}

% Associated counters

\setcounter{secnumdepth}{3}
\renewcommand\thesection{\thechapter.\Alph{section}}
\renewcommand\thesubsubsection{\thesubsection.\alph{subsubsection}}

% TABLE OF CONTENTS

\setcounter{tocdepth}{3}

\renewcommand\contentsname{Table of Contents}
\newcommand{\headcontentsname}{Contents}
\renewcommand\tableofcontents{%
   \if@twocolumn
      \@restonecoltrue\onecolumn
   \else
      \@restonecolfalse
   \fi
   \chapter*{\contentsname
      \@mkboth{\MakeUppercase\headcontentsname}%
              {\MakeUppercase\headcontentsname}}%
   \hspace*{\fill}\textbf{Page}\par
   \@starttoc{toc}\if@restonecol\twocolumn\fi}

\renewcommand*\l@part[2]{%
  \ifnum \c@tocdepth >-2\relax
    \addpenalty{-\@highpenalty}%
    \addvspace{2em \@plus\p@}%
    \setlength\@tempdima{3em}%
    \begingroup
      \parindent \z@ \rightskip \@pnumwidth
      \parfillskip -\@pnumwidth
      {\leavevmode
       \large \bfseries \MakeUppercase{#1}\hfil%
       \hb@xt@\@pnumwidth{\hss #2}}\par
       \nobreak
         \global\@nobreaktrue
         \everypar{\global\@nobreakfalse\everypar{}}%
    \endgroup
  \fi}
  
\renewcommand*\l@chapter[2]{%
  \ifnum \c@tocdepth >\m@ne
    \addpenalty{-\@highpenalty}%
    \vskip 2em \@plus\p@
    \setlength\@tempdima{1.5em}%
    \begingroup
      \parindent \z@ \rightskip \@pnumwidth
      \parfillskip -\@pnumwidth
      \leavevmode \bfseries
      \advance\leftskip\@tempdima
      \hskip -\leftskip
      \MakeUppercase{#1}\nobreak\hfil \nobreak%
      \hb@xt@\@pnumwidth{\hss #2}\par
      \penalty\@highpenalty
    \endgroup
    \vskip .5em plus 1pt
  \fi}

\renewcommand*\l@section{\@dottedtocline{1}{2.5em}{3 em}}
\renewcommand*\l@subsection{\@dottedtocline{2}{5.5em}{4.0em}}
\renewcommand*\l@subsubsection{\@dottedtocline{3}{9.5em}{5em}}
\renewcommand*\l@paragraph{\@dottedtocline{4}{14.5em}{6em}}
\renewcommand*\l@subparagraph{\@dottedtocline{5}{20.5em}{7em}}

% LIST OF FIGURES AND LIST OF TABLES

\renewcommand\listoffigures{%
    \if@twocolumn
      \@restonecoltrue\onecolumn
    \else
      \@restonecolfalse
    \fi
    \chapter*{\listfigurename}%
      \@mkboth{\MakeUppercase\listfigurename}%
              {\MakeUppercase\listfigurename}%
    {\noindent \bfseries Figure \hfill Page}\par%
    \@starttoc{lof}%
    \if@restonecol\twocolumn\fi}
    
\renewcommand*\l@figure{\@dottedtocline{1}{0em}{2.5em}}

\renewcommand\listoftables{%
    \if@twocolumn
      \@restonecoltrue\onecolumn
    \else
      \@restonecolfalse
    \fi
    \chapter*{\listtablename}%
      \@mkboth{\MakeUppercase\listtablename}%
              {\MakeUppercase\listtablename}%
    {\noindent \bfseries Table \hfill Page}\par%
    \@starttoc{lot}%
    \if@restonecol\twocolumn\fi}
    
\let\l@table\l@figure

% BIBLIOGRAPHY

\renewcommand\bibname{References}
\renewenvironment{thebibliography}[1]
     {\chapter*{\bibname}%
      \@mkboth{\MakeUppercase\bibname}{\MakeUppercase\bibname}%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \setlength{\itemsep}{0.6\itemsep}
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}

% CAPTIONS

\setlength\abovecaptionskip{24\p@} % 10pt in the report class
\setlength\belowcaptionskip{24\p@} %  0pt
\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{#1 #2}%
  \ifdim \wd\@tempboxa >\hsize
    #1 #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}

\endinput
